@@ -1,7 +1,7 @@
 use custom_utils::*;
 
 fn main() {
-    let _logger = default_debug_logger("prod").unwrap();
+    let _logger = logger_default_debug("prod").unwrap();
     debug!("abc");
     info!("abc");
 }
